@@ -5,10 +5,8 @@ import numpy as np
 import pysbd
 import torch
 
-from TTS.config import check_config_and_model_args, get_from_config_or_model_args_with_default, load_config
+from TTS.config import load_config
 from TTS.tts.models import setup_model as setup_tts_model
-from TTS.tts.utils.languages import LanguageManager
-from TTS.tts.utils.speakers import SpeakerManager
 
 # pylint: disable=unused-wildcard-import
 # pylint: disable=wildcard-import
@@ -110,25 +108,12 @@ class Synthesizer(object):
             use_cuda (bool): enable/disable CUDA use.
         """
         # pylint: disable=global-statement
-
         self.tts_config = load_config(tts_config_path)
         self.use_phonemes = self.tts_config.use_phonemes
-        self.ap = AudioProcessor(verbose=False, **self.tts_config.audio)
+        self.tts_model = setup_tts_model(config=self.tts_config)
 
-        speaker_manager = self._init_speaker_manager()
-        language_manager = self._init_language_manager()
         if not self.encoder_checkpoint:
             self._set_speaker_encoder_paths_from_tts_config()
-        speaker_manager = self._init_speaker_encoder(speaker_manager)
-
-        if language_manager is not None:
-            self.tts_model = setup_tts_model(
-                config=self.tts_config,
-                speaker_manager=speaker_manager,
-                language_manager=language_manager,
-            )
-        else:
-            self.tts_model = setup_tts_model(config=self.tts_config, speaker_manager=speaker_manager)
         self.tts_model.load_checkpoint(self.tts_config, tts_checkpoint, eval=True)
         if use_cuda:
             self.tts_model.cuda()
@@ -141,69 +126,6 @@ class Synthesizer(object):
             self.encoder_checkpoint = self.tts_config.model_args.speaker_encoder_model_path
             self.encoder_config = self.tts_config.model_args.speaker_encoder_config_path
 
-    def _is_use_speaker_embedding(self):
-        """Check if the speaker embedding is used in the model"""
-        # we handle here the case that some models use model_args some don't
-        use_speaker_embedding = False
-        if hasattr(self.tts_config, "model_args"):
-            use_speaker_embedding = self.tts_config["model_args"].get("use_speaker_embedding", False)
-        use_speaker_embedding = use_speaker_embedding or self.tts_config.get("use_speaker_embedding", False)
-        return use_speaker_embedding
-
-    def _is_use_d_vector_file(self):
-        """Check if the d-vector file is used in the model"""
-        # we handle here the case that some models use model_args some don't
-        use_d_vector_file = False
-        if hasattr(self.tts_config, "model_args"):
-            config = self.tts_config.model_args
-            use_d_vector_file = config.get("use_d_vector_file", False)
-        config = self.tts_config
-        use_d_vector_file = use_d_vector_file or config.get("use_d_vector_file", False)
-        return use_d_vector_file
-
-    def _init_speaker_manager(self):
-        """Initialize the SpeakerManager"""
-        # setup if multi-speaker settings are in the global model config
-        speaker_manager = None
-        speakers_file = get_from_config_or_model_args_with_default(self.tts_config, "speakers_file", None)
-        if self._is_use_speaker_embedding():
-            if self.tts_speakers_file:
-                speaker_manager = SpeakerManager(speaker_id_file_path=self.tts_speakers_file)
-            elif speakers_file:
-                speaker_manager = SpeakerManager(speaker_id_file_path=speakers_file)
-
-        if self._is_use_d_vector_file():
-            d_vector_file = get_from_config_or_model_args_with_default(self.tts_config, "d_vector_file", None)
-            if self.tts_speakers_file:
-                speaker_manager = SpeakerManager(d_vectors_file_path=self.tts_speakers_file)
-            elif d_vector_file:
-                speaker_manager = SpeakerManager(d_vectors_file_path=d_vector_file)
-        return speaker_manager
-
-    def _init_speaker_encoder(self, speaker_manager):
-        """Initialize the SpeakerEncoder"""
-        if self.encoder_checkpoint:
-            if speaker_manager is None:
-                speaker_manager = SpeakerManager(
-                    encoder_model_path=self.encoder_checkpoint, encoder_config_path=self.encoder_config
-                )
-            else:
-                speaker_manager.init_speaker_encoder(self.encoder_checkpoint, self.encoder_config)
-        return speaker_manager
-
-    def _init_language_manager(self):
-        """Initialize the LanguageManager"""
-        # setup if multi-lingual settings are in the global model config
-        language_manager = None
-        if check_config_and_model_args(self.tts_config, "use_language_embedding", True):
-            if self.tts_languages_file:
-                language_manager = LanguageManager(language_ids_file_path=self.tts_languages_file)
-            elif self.tts_config.get("language_ids_file", None):
-                language_manager = LanguageManager(language_ids_file_path=self.tts_config.language_ids_file)
-            else:
-                language_manager = LanguageManager(config=self.tts_config)
-        return language_manager
-
     def _load_vocoder(self, model_file: str, model_config: str, use_cuda: bool) -> None:
         """Load the vocoder model.
 
@@ -243,7 +165,7 @@ class Synthesizer(object):
             path (str): output path to save the waveform.
         """
         wav = np.array(wav)
-        self.ap.save_wav(wav, path, self.output_sample_rate)
+        self.tts_model.ap.save_wav(wav, path, self.output_sample_rate)
 
     def tts(
         self,
@@ -331,12 +253,9 @@ class Synthesizer(object):
                 text=sen,
                 CONFIG=self.tts_config,
                 use_cuda=self.use_cuda,
-                ap=self.ap,
                 speaker_id=speaker_id,
                 language_id=language_id,
-                language_name=language_name,
                 style_wav=style_wav,
-                enable_eos_bos_chars=self.tts_config.enable_eos_bos_chars,
                 use_griffin_lim=use_gl,
                 d_vector=speaker_embedding,
             )
@@ -344,14 +263,14 @@ class Synthesizer(object):
             mel_postnet_spec = outputs["outputs"]["model_outputs"][0].detach().cpu().numpy()
             if not use_gl:
                 # denormalize tts output based on tts audio config
-                mel_postnet_spec = self.ap.denormalize(mel_postnet_spec.T).T
+                mel_postnet_spec = self.tts_model.ap.denormalize(mel_postnet_spec.T).T
                 device_type = "cuda" if self.use_cuda else "cpu"
                 # renormalize spectrogram based on vocoder config
                 vocoder_input = self.vocoder_ap.normalize(mel_postnet_spec.T)
                 # compute scale factor for possible sample rate mismatch
                 scale_factor = [
                     1,
-                    self.vocoder_config["audio"]["sample_rate"] / self.ap.sample_rate,
+                    self.vocoder_config["audio"]["sample_rate"] / self.tts_model.ap.sample_rate,
                 ]
                 if scale_factor[1] != 1:
                     print(" > interpolating tts model output.")
@@ -369,7 +288,7 @@ class Synthesizer(object):
 
             # trim silence
             if self.tts_config.audio["do_trim_silence"] is True:
-                waveform = trim_silence(waveform, self.ap)
+                waveform = trim_silence(waveform, self.tts_model.ap)
 
             wavs += list(waveform)
             wavs += [0] * 10000
